@@ -3,6 +3,8 @@
 utils::globalVariables(
   names = c(
     ".",
+    "conf.level",
+    "nboot",
     "U",
     "V",
     "Z",
@@ -93,6 +95,8 @@ utils::globalVariables(
     "coef",
     "conf.high",
     "conf.low",
+    "mean.high.conf",
+    "mean.low.conf",
     "rowid",
     "Cramer's V",
     "df[chiSq]",
@@ -117,7 +121,49 @@ utils::globalVariables(
     "or",
     "atop",
     "top.text",
-    "bottom.text"
+    "bottom.text",
+    "code",
+    "time",
+    "t-value",
+    "Group",
+    "Group1",
+    "group1",
+    "group2",
+    "Group..1",
+    "Group..2",
+    "ci.lower",
+    "ci.upper",
+    "comparison",
+    "p",
+    "p1",
+    "p2",
+    "high.conf",
+    "i1",
+    "i2",
+    "key",
+    "low.conf",
+    "mean.difference",
+    "p.crit",
+    "sep",
+    "value",
+    "var",
+    "label2",
+    "p.value.label",
+    "sampling.plan",
+    "displaystyle",
+    "textstyle",
+    "a",
+    "x",
+    "bf01",
+    "bf10",
+    "log_10_bf01",
+    "log_10_bf10",
+    "log_e_bf01",
+    "log_e_bf10",
+    "2.5 %",
+    "97.5 %",
+    "group",
+    "name"
   ),
   package = "ggstatsplot",
   add = FALSE
