@@ -5,6 +5,10 @@ knitr::opts_chunk$set(
 )
 
 ## ----aov1, warning = FALSE, message = FALSE, fig.height = 6, fig.width = 8----
+# loading needed libraries
+library(ggstatsplot)
+library(ggplot2)
+
 # for reproducibility
 set.seed(123)
 
@@ -20,7 +24,7 @@ ggstatsplot::ggcoefstats(
     formula = rating ~ mpaa * genre,
     data = movies_10
   ),
-  effsize = "omega",                        # changing the effect size estimate being displayed
+  effsize = "eta",                          # changing the effect size estimate being displayed
   point.color = "red",                      # changing the point color
   point.size = 4,                           # changing the point size
   point.shape = 15,                         # changing the point shape
@@ -34,55 +38,56 @@ ggstatsplot::ggcoefstats(
   ggplot2::labs(x = "effect size estimate (partial omega-squared)",
                 y = NULL)
 
-## ----aov2, warning = FALSE, message = FALSE, fig.height = 10, fig.width = 10----
-library(ggstatsplot)
-
-# to speed up the calculation, let's use only 10% of the data
-movies_10 <- dplyr::sample_frac(tbl = ggstatsplot::movies_long, size = 0.1)
-
-# for reproducibility
-set.seed(123)
-
-# plot
-ggstatsplot::combine_plots(
-  # model 1
-  ggstatsplot::ggcoefstats(
-    x = stats::aov(
-      formula = rating ~ mpaa,
-      data = movies_10
-    ),
-    stats.label.color = "black",
-    title = "1. Only MPAA ratings"
-  ),
-  ggstatsplot::ggcoefstats(
-    x = stats::aov(
-      formula = rating ~ genre,
-      data = movies_10
-    ),
-    stats.label.color = "black",
-    title = "2. Only genre"
-  ),
-  ggstatsplot::ggcoefstats(
-    x = stats::aov(
-      formula = rating ~ mpaa + genre,
-      data = movies_10
-    ),
-    stats.label.color = "black",
-    title = "3. Additive effect of MPAA and genre"
-  ),
-  ggstatsplot::ggcoefstats(
-    x = stats::aov(
-      formula = rating ~ mpaa * genre,
-      data = movies_10
-    ),
-    stats.label.color = "black",
-    title = "4. Multiplicative effect of MPAA and genre"
-  ),
-  title.text = "Model selection using ggcoefstats",
-  labels = c("(a)", "(b)", "(c)", "(d)")
-)
+## ----aov2, warning = FALSE, message = FALSE, fig.height = 10, fig.width = 10, eval = FALSE----
+#  library(ggstatsplot)
+#  
+#  # to speed up the calculation, let's use only 10% of the data
+#  movies_10 <- dplyr::sample_frac(tbl = ggstatsplot::movies_long, size = 0.1)
+#  
+#  # for reproducibility
+#  set.seed(123)
+#  
+#  # plot
+#  ggstatsplot::combine_plots(
+#    # model 1
+#    ggstatsplot::ggcoefstats(
+#      x = stats::aov(
+#        formula = rating ~ mpaa,
+#        data = movies_10
+#      ),
+#      stats.label.color = "black",
+#      title = "1. Only MPAA ratings"
+#    ),
+#    ggstatsplot::ggcoefstats(
+#      x = stats::aov(
+#        formula = rating ~ genre,
+#        data = movies_10
+#      ),
+#      stats.label.color = "black",
+#      title = "2. Only genre"
+#    ),
+#    ggstatsplot::ggcoefstats(
+#      x = stats::aov(
+#        formula = rating ~ mpaa + genre,
+#        data = movies_10
+#      ),
+#      stats.label.color = "black",
+#      title = "3. Additive effect of MPAA and genre"
+#    ),
+#    ggstatsplot::ggcoefstats(
+#      x = stats::aov(
+#        formula = rating ~ mpaa * genre,
+#        data = movies_10
+#      ),
+#      stats.label.color = "black",
+#      title = "4. Multiplicative effect of MPAA and genre"
+#    ),
+#    title.text = "Model selection using ggcoefstats",
+#    labels = c("(a)", "(b)", "(c)", "(d)")
+#  )
 
 ## ----anova1, warning = FALSE, message = FALSE, fig.height = 6, fig.width = 8----
+# dataset will be used from `car` package
 library(car)
 
 # creating a model
@@ -119,12 +124,14 @@ ggstatsplot::ggcoefstats(
   # further modification with the ggplot2 commands
   # note the order in which the labels are entered
   ggplot2::scale_y_discrete(labels = c("Comedy", "Romance", "Documentary", "Animation", "Drama")) +
-  ggplot2::labs(y = "genre (comparison level: Action)") + 
+  ggplot2::labs(y = "genre (comparison level: Action)") +
   ggplot2::theme(axis.title.y = ggplot2::element_text(size = 14, face = "bold"))
 
 ## ----lmer1, warning = FALSE, message = FALSE, fig.height = 14, fig.width = 7----
+# set up
 library(lme4)
 library(ggstatsplot)
+set.seed(123)
 
 # to speed up the calculation, let's use only 10% of the data
 movies_10 <- dplyr::sample_frac(tbl = ggstatsplot::movies_long, size = 0.1)
@@ -139,7 +146,7 @@ ggstatsplot::combine_plots(
     ),
     title = "linear model",
     stats.label.color = "black",
-    exclude.intercept = FALSE                       # show the intercept
+    exclude.intercept = FALSE              # show the intercept
   ) +
     ggplot2::labs(x = parse(text = "'standardized regression coefficient' ~italic(beta)")),
   # model 2: linear mixed-effects model
@@ -149,10 +156,10 @@ ggstatsplot::combine_plots(
       data = movies_10,
       control = lme4::lmerControl(calc.derivs = FALSE)
     ),
-    p.kr = TRUE,                                    # use Kenward-Roger approximation to compute p-values (fast)
+    p.kr = FALSE,
     title = "linear mixed-effects model",
     stats.label.color = "black",
-    exclude.intercept = FALSE                       # show the intercept
+    exclude.intercept = FALSE              # show the intercept
   ) +
     ggplot2::labs(x = parse(text = "'standardized regression coefficient' ~italic(beta)"), 
                   y = "fixed effects"),
@@ -163,13 +170,11 @@ ggstatsplot::combine_plots(
 )
 
 ## ----lmer2, warning = FALSE, message = FALSE-----------------------------
-library(ggstatsplot)
-
 # to speed up the calculation, let's use only 10% of the data
 movies_10 <- dplyr::sample_frac(tbl = ggstatsplot::movies_long, size = 0.1)
 
 # tidy output
-broom::tidy(
+broom.mixed::tidy(
   x = lme4::lmer(
     formula = scale(rating) ~ scale(budget) + (budget | genre),
     data = movies_10,
@@ -179,6 +184,22 @@ broom::tidy(
   conf.level = 0.95
 )
 
+## ----rlmer, warning = FALSE, message = FALSE-----------------------------
+set.seed(123)
+library(robustlmm)
+
+# model
+roblmm.mod <- robustlmm::rlmer(
+  formula = scale(Reaction) ~ scale(Days) + (Days | Subject),
+  data = sleepstudy,
+  rho.sigma.e = psi2propII(smoothPsi, k = 2.28),
+  rho.sigma.b = chgDefaults(smoothPsi, k = 5.11, s = 10)
+)
+
+# plot
+ggstatsplot::ggcoefstats(x = roblmm.mod,
+                         title = "Robust Estimation of Linear Mixed-Effects Models")
+
 ## ----nls, warning = FALSE, message = FALSE, fig.height = 6, fig.width = 6----
 library(ggstatsplot)
 
@@ -188,7 +209,7 @@ movies_10 <- dplyr::sample_frac(tbl = ggstatsplot::movies_long, size = 0.1)
 # plot
 ggstatsplot::ggcoefstats(
     x = stats::nls(
-      formula = rating ~ k / budget + c,                # try toying around with the form of non-linear function
+      formula = rating ~ k / budget + c,     # try toying around with the form of non-linear function
       data = movies_10,
       start = list(k = 1, c = 0)
     ),
@@ -212,7 +233,8 @@ ggstatsplot::ggcoefstats(
     family = stats::binomial(link = "logit")    # choosing the family
   ),
   exponentiate = TRUE,
-  ggtheme = ggplot2::theme_dark(),
+  ggtheme = ggthemes::theme_economist_white(),
+  title = "general linear model (glm)",
   vline.color = "red",
   vline.linetype = "solid",
   label.segment.color = "red",
@@ -221,9 +243,9 @@ ggstatsplot::ggcoefstats(
                         "dodgerblue")
 ) 
 
-## ----glm2, warning = FALSE, message = FALSE, fig.height = 12, fig.width = 10----
+## ----glm2, warning = FALSE, message = FALSE, fig.height = 13, fig.width = 10----
 # creating dataframes to use for regression analyses
-library(dplyr)
+library(ggstatsplot)
 
 # dataframe #1
 (
@@ -245,14 +267,14 @@ library(dplyr)
   tibble::as_data_frame(x = .))
 
 # dataframe #3
-x1 <- stats::rnorm(100)
-y1 <- stats::rpois(n = 100, lambda = exp(1 + x1))
+x1 <- stats::rnorm(50)
+y1 <- stats::rpois(n = 50, lambda = exp(1 + x1))
 (df.3 <- data.frame(x = x1, y = y1) %>%
     tibble::as_data_frame(x = .))
 
 # dataframe #4
-x2 <- stats::rnorm(100)
-y2 <- rbinom(n = 100,
+x2 <- stats::rnorm(50)
+y2 <- rbinom(n = 50,
              size = 1,
              prob = stats::plogis(x2))
 
@@ -323,7 +345,8 @@ ggstatsplot::combine_plots(
   ),
   labels = c("(a)", "(b)", "(c)", "(d)", "(e)", "(f)"),
   ncol = 2,
-  title.text = "Exploring models with different glm families"
+  title.text = "Exploring models with different `glm` families",
+  title.color = "blue"
 )
 
 ## ----glmer, warning = FALSE, message = FALSE, fig.height = 6, fig.width = 6----
@@ -331,8 +354,8 @@ ggstatsplot::combine_plots(
 ggstatsplot::ggcoefstats(
   x = lme4::glmer(
     formula = Survived ~ Sex + Age + (Sex + Age | Class),
-    # select 30% of the sample to reduce the time of execution
-    data = dplyr::sample_frac(tbl = ggstatsplot::Titanic_full, size = 0.3),
+    # select 20% of the sample to reduce the time of execution
+    data = dplyr::sample_frac(tbl = ggstatsplot::Titanic_full, size = 0.2),
     family = stats::binomial(link = "logit"),
     control = lme4::glmerControl(
       optimizer = "Nelder_Mead",
@@ -344,118 +367,100 @@ ggstatsplot::ggcoefstats(
   stats.label.color = "black"
 )
 
-## ----clm, warning = FALSE, message = FALSE, fig.height = 12, fig.width = 12----
-library(ggstatsplot)
-library(purrr)
-library(glue)
+## ----glmmTMB, warning = FALSE, message = FALSE, fig.height = 5, fig.width = 6----
+# set up
+library(glmmTMB)
+library(lme4)
+set.seed(123)
 
-# running the function for each type of harm and creating a list of plots
-# to speed up calculations, we will use just 25% of the dataset
-plotlist <- dplyr::sample_frac(tbl = ggstatsplot::intent_morality, size = 0.25) %>%
-  dplyr::mutate(.data = ., plot.title = harm) %>%
-  base::split(x = ., f = .$harm) %>%
-  purrr::map(
-    .x = .,
-    .f = ~ ggstatsplot::ggcoefstats(
-      x = ordinal::clm(
-        formula = as.factor(rating) ~ belief * outcome,
-        link = "logit",
-        data = .,
-        control = ordinal::clm.control(
-          maxIter = 50,
-          convergence = "silent"
-        ),
-      ),
-      stats.label.color = "black",
-      title = glue::glue("Type of harm: {.$plot.title}"),
-      caption.summary = FALSE                            # suppress model diagnostics
-    ) +
-      ggplot2::labs(x = "logit regression coefficient",
-                    y = NULL)
+# model
+mod <-
+  glmmTMB::glmmTMB(
+    formula = Reaction ~ Days + (Days |
+                                   Subject),
+    data = sleepstudy,
+    family = glmmTMB::truncated_poisson()
   )
 
-# combining the plots
-ggstatsplot::combine_plots(plotlist = plotlist)
+# plotting the model
+ggstatsplot::ggcoefstats(x = mod,
+                         conf.method = "uniroot")
 
+## ----clm, warning = FALSE, message = FALSE, fig.height = 6, fig.width = 6, eval = FALSE----
+#  # for reproducibility
+#  set.seed(123)
+#  
+#  # to speed up calculations, we will use just 10% of the dataset
+#  ggstatsplot::ggcoefstats(
+#    x = ordinal::clm(
+#      formula = as.factor(rating) ~ belief * outcome,
+#      link = "logit",
+#      data = dplyr::sample_frac(tbl = ggstatsplot::intent_morality, size = 0.10),
+#      control = ordinal::clm.control(maxIter = 50,
+#                                     convergence = "silent"),
+#    ),
+#    stats.label.color = "black",
+#    title = "Cumulative Link Model (clm)",
+#    subtitle = "(Using `ordinal` package)",
+#    caption.summary = FALSE                            # suppress model diagnostics
+#  ) +
+#    ggplot2::labs(x = "logit regression coefficient",
+#                  y = NULL)
 
-## ----clmm1, warning = FALSE, message = FALSE, fig.height = 6, fig.width = 6----
-library(ggstatsplot)
+## ----clmm1, warning = FALSE, message = FALSE, fig.height = 6, fig.width = 6, eval = FALSE----
+#  # for reproducibility
+#  set.seed(123)
+#  
+#  # to speed up calculations, we will use just 10% of the dataset
+#  ggstatsplot::ggcoefstats(
+#    x = ordinal::clmm(
+#      formula = as.factor(rating) ~ belief * outcome + (belief + outcome |
+#                                                          harm),
+#      data = dplyr::sample_frac(tbl = ggstatsplot::intent_morality, size = 0.10),
+#      control = ordinal::clmm.control(
+#        method = "nlminb",
+#        maxIter = 50,
+#        gradTol = 1e-4,
+#        innerCtrl = "noWarn"
+#      )
+#    ),
+#    title = "Cumulative Link Mixed Model (clmm)",
+#      subtitle = "(Using `ordinal` package)"
+#  ) +
+#    ggplot2::labs(x = "coefficient from ordinal mixed-effects regression",
+#                  y = "fixed effects")
 
-ggstatsplot::ggcoefstats(
-  x = ordinal::clmm(
-    formula = as.factor(rating) ~ belief * outcome + (belief + outcome |
-                                                        harm),
-    # to speed up calculations, we will use just 30% of the dataset
-    data = dplyr::sample_frac(tbl = ggstatsplot::intent_morality, size = 0.3),
-    control = ordinal::clmm.control(
-      method = "nlminb",
-      maxIter = 50,
-      gradTol = 1e-4,
-      innerCtrl = "noWarn"
-    )
-  ),
-  # suppress model diagnostics
-  caption.summary = FALSE
-) +
-  #ggplot2::scale_y_discrete(labels = c("belief (neutral)", "interaction", "outcome (neutral)")) +
-  ggplot2::labs(x = "coefficient from ordinal mixed-effects regression",
-                y = "fixed effects")
-
-## ----clmm2, warning = FALSE, message = FALSE, fig.height = 6, fig.width = 6----
-library(ggstatsplot)
-
-# to speed up calculations, we will use just 30% of the dataset
-ggstatsplot::ggcoefstats(
-  x = ordinal::clmm(
-    formula = as.factor(rating) ~ belief * outcome + (belief + outcome |
-                                                        harm),
-    link = "logit",
-    data = dplyr::sample_frac(tbl = ggstatsplot::intent_morality, size = 0.3),
-    control = ordinal::clmm.control(
-      maxIter = 50,
-      gradTol = 1e-4,
-      innerCtrl = "noWarn"
-    )
-  ),
-  coefficient.type = "alpha"
-) +
-  ggplot2::labs(x = "logit regression coefficients",
-                y = "threshold parameters")
+## ----clmm2, warning = FALSE, message = FALSE, fig.height = 6, fig.width = 6, eval = FALSE----
+#  # for reproducibility
+#  set.seed(123)
+#  
+#  # to speed up calculations, we will use just 10% of the dataset
+#  ggstatsplot::ggcoefstats(
+#    x = ordinal::clmm(
+#      formula = as.factor(rating) ~ belief * outcome + (belief + outcome |
+#                                                          harm),
+#      link = "logit",
+#      data = dplyr::sample_frac(tbl = ggstatsplot::intent_morality, size = 0.10),
+#      control = ordinal::clmm.control(
+#        maxIter = 50,
+#        gradTol = 1e-4,
+#        innerCtrl = "noWarn"
+#      )
+#    ),
+#    coefficient.type = "alpha"
+#  ) +
+#    ggplot2::labs(x = "logit regression coefficients",
+#                  y = "threshold parameters")
 
 ## ----aovlist1, warning = FALSE, message = FALSE, fig.height = 6, fig.width = 8----
-library(ggstatsplot)
-library(ggplot2)
-
 # for reproducibility
 set.seed(123)
 
 # having a look at iris before converting to long format
-dplyr::glimpse(iris)
-
-# converting the iris dataset to long format
-iris_long <- datasets::iris %>%
-  dplyr::mutate(.data = ., id = dplyr::row_number(x = Species)) %>%
-  tidyr::gather(
-    data = .,
-    key = "condition",
-    value = "value",
-    Sepal.Length:Petal.Width,
-    convert = TRUE,
-    factor_key = TRUE
-  ) %>%
-  tidyr::separate(
-    col = "condition",
-    into = c("attribute", "measure"),
-    sep = "\\.",
-    convert = TRUE
-  ) %>%
-  tibble::as_data_frame(x = .)
-
-# looking at the long format data
-dplyr::glimpse(x = iris_long)
+dplyr::glimpse(ggstatsplot::iris_long)
 
 # let's use 20% of the sample to speed up the analysis
-iris_long_20 <- dplyr::sample_frac(tbl = iris_long, size = 0.20)
+iris_long_20 <- dplyr::sample_frac(tbl = ggstatsplot::iris_long, size = 0.20)
 
 # specifying the model (note the error structure)
 ggstatsplot::ggcoefstats(
@@ -471,7 +476,7 @@ ggstatsplot::ggcoefstats(
   subtitle = "Source: Iris data set (by Fisher or Anderson)"
 ) + 
   ggplot2::labs(caption = "Results from 2 by 2 RM ANOVA") + 
-  ggplot2::theme(plot.subtitle = element_text(size = 11, face = "plain"))
+  ggplot2::theme(plot.subtitle = ggplot2::element_text(size = 11, face = "plain"))
 
 ## ----robust, warning = FALSE, message = FALSE, fig.height = 12, fig.width = 8----
 ggstatsplot::combine_plots(
@@ -479,7 +484,7 @@ ggstatsplot::combine_plots(
   ggstatsplot::ggcoefstats(
     x = robust::glmRob(
       formula = Survived ~ Sex,
-      data = dplyr::sample_frac(tbl = ggstatsplot::Titanic_full, size = 0.25),
+      data = dplyr::sample_frac(tbl = ggstatsplot::Titanic_full, size = 0.20),
       family = stats::binomial(link = "logit")
     ),
     title = "generalized robust linear model",
@@ -505,7 +510,71 @@ ggstatsplot::combine_plots(
   ncol = 1
 )
 
-## ----session_info-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-options(width = 200)
-devtools::session_info()
+## ----felm, warning = FALSE, message = FALSE, fig.height = 6, fig.width = 6----
+library(lfe)
+
+# create covariates
+x <- rnorm(1000)
+x2 <- rnorm(length(x))
+
+# individual and firm
+id <- factor(sample(20, length(x), replace = TRUE))
+firm <- factor(sample(13, length(x), replace = TRUE))
+
+# effects for them
+id.eff <- rnorm(nlevels(id))
+firm.eff <- rnorm(nlevels(firm))
+
+# left hand side
+u <- rnorm(length(x))
+y <- x + 0.5 * x2 + id.eff[id] + firm.eff[firm] + u
+
+# estimate and print result
+est <- lfe::felm(formula = y ~ x + x2 | id + firm)
+
+# plot
+ggstatsplot::ggcoefstats(x = est)
+
+
+## ----dataframe, warning = FALSE, message = FALSE, fig.height = 6, fig.width = 6----
+# set up
+set.seed(123)
+library(ggstatsplot)
+library(gapminder)
+
+# data for running regression models
+df <-
+  dplyr::filter(.data = gapminder::gapminder, continent != "Oceania")
+
+# saving results from regression  
+df_results <- purrr::pmap(
+  .l = list(
+    data = list(df),
+    formula = list(scale(lifeExp) ~ scale(gdpPercap) + (gdpPercap |
+                                                          country)),
+    grouping.vars = alist(continent),
+    output = list("tidy", "glance")
+  ),
+  .f = groupedstats::grouped_lmer
+) %>%
+  dplyr::full_join(x = .[[1]], y = .[[2]], by = "continent")
+
+# modifying the results so to be compatible with the `ggcoefstats` requirement
+(df_results %<>%
+  dplyr::filter(.data = ., term != "(Intercept)") %>%
+  dplyr::select(.data = .,
+                -effect,
+                -term,
+                term = continent,
+                statistic = t.value))
+
+# plot
+ggstatsplot::ggcoefstats(
+  x = df_results,
+  statistic = "t",
+  sort = "ascending",
+  title = "Relationship between life expectancy and GDP",
+  subtitle = "Source: Gapminder foundation",
+  caption = "Data from Oceania continent not included"
+)
 
